@@ -16,6 +16,11 @@ module Vagrant
   class Box
     include Comparable
 
+    autoload :Remote, "vagrant/box/remote"
+
+    # The required fields in a boxes `metadata.json` file
+    REQUIRED_METADATA_FIELDS = ["provider"]
+
     # Number of seconds to wait between checks for box updates
     BOX_UPDATE_CHECK_INTERVAL = 3600
 
@@ -72,6 +77,7 @@ module Vagrant
 
       begin
         @metadata = JSON.parse(directory.join("metadata.json").read)
+        validate_metadata_json(@metadata)
       rescue JSON::ParserError
         raise Errors::BoxMetadataCorrupted, name: @name
       end
@@ -79,6 +85,18 @@ module Vagrant
       @logger = Log4r::Logger.new("vagrant::box")
     end
 
+    def validate_metadata_json(metadata)
+      metatdata_fields = metadata.keys
+      REQUIRED_METADATA_FIELDS.each do |field|
+        if !metatdata_fields.include?(field)
+          raise Errors::BoxMetadataMissingRequiredFields,
+            name: @name,
+            required_field: field,
+            all_fields: REQUIRED_METADATA_FIELDS.join(", ")
+        end
+      end
+    end
+
     # This deletes the box. This is NOT undoable.
     def destroy!
       # Delete the directory to delete the box.
@@ -140,7 +158,7 @@ module Vagrant
         @hook.call(:authenticate_box_downloader, downloader: d)
       end
       d.download!
-      BoxMetadata.new(File.open(tf.path, "r"))
+      BoxMetadata.new(File.open(tf.path, "r"), url: url)
     rescue Errors::DownloaderError => e
       raise Errors::BoxMetadataDownloadError,
         message: e.extra_data[:message]
