@@ -168,6 +168,10 @@ module Vagrant
       error_key(:box_metadata_corrupted)
     end
 
+    class BoxMetadataMissingRequiredFields < VagrantError
+      error_key(:box_metadata_missing_required_fields)
+    end
+
     class BoxMetadataDownloadError < VagrantError
       error_key(:box_metadata_download_error)
     end
@@ -240,6 +244,10 @@ module Vagrant
       error_key(:failed, "vagrant.actions.box.verify")
     end
 
+    class BoxVersionInvalid < VagrantError
+      error_key(:box_version_invalid)
+    end
+
     class BundlerDisabled < VagrantError
       error_key(:bundler_disabled)
     end
@@ -928,6 +936,10 @@ module Vagrant
       error_key(:vagrantfile_name_error)
     end
 
+    class VagrantRemoteError < VagrantError
+      error_key(:vagrant_remote_error)
+    end
+
     class VagrantfileSyntaxError < VagrantError
       error_key(:vagrantfile_syntax_error)
     end
@@ -960,6 +972,10 @@ module Vagrant
       error_key(:virtualbox_broken_version_040214)
     end
 
+    class VirtualBoxConfigNotFound < VagrantError
+      error_key(:virtualbox_config_not_found)
+    end
+
     class VirtualBoxDisksDefinedExceedLimit < VagrantError
       error_key(:virtualbox_disks_defined_exceed_limit)
     end
@@ -1004,6 +1020,10 @@ module Vagrant
       error_key(:virtualbox_install_incomplete)
     end
 
+    class VirtualBoxMachineFolderNotFound < VagrantError
+      error_key(:virtualbox_machine_folder_not_found)
+    end
+
     class VirtualBoxNoName < VagrantError
       error_key(:virtualbox_no_name)
     end
