@@ -24,7 +24,26 @@ module Vagrant
         #
         # @return [V2::Manager]
         def self.manager
-          @manager ||= Manager.new
+          @manager ||= local_manager
+        end
+
+        def self.local_manager
+          @_manager ||= Manager.new
+        end
+
+        def self.remote_manager
+          @_remote_manager ||= Remote::Manager.new(local_manager)
+        end
+
+        def self.enable_remote_manager(client, core_client: nil)
+          Remote::Manager.client = client
+          Remote::Manager.core_client = core_client
+          @manager = remote_manager
+        end
+
+        def self.disable_remote_manager
+          Remote::Manager.client = nil
+          @manager = local_manager
         end
 
         # Returns the {Components} for this plugin.
@@ -247,6 +266,18 @@ module Vagrant
           nil
         end
 
+        # Defines a capability for the given synced folder. The block should return
+        # a class/module that has a method with the capability name, ready
+        # to be executed. This means that if it is an instance method,
+        # the block should return an instance of the class.
+        #
+        # @param [String] synced_folder The name of the synced folder
+        # @param [String] cap The name of the capability
+        def self.synced_folder_capability(synced_folder, cap, &block)
+          components.synced_folder_capabilities[synced_folder.to_sym].register(cap.to_sym, &block)
+          nil
+        end
+
         # Returns the internal data associated with this plugin. This
         # should NOT be called by the general public.
         #
@@ -258,7 +289,7 @@ module Vagrant
         protected
 
         # Sentinel value denoting that a value has not been set.
-        UNSET_VALUE = Object.new
+        UNSET_VALUE = :__UNSET__VALUE__
 
         # Helper method that will set a value if a value is given, or otherwise
         # return the already set value.
