@@ -14,6 +14,9 @@ module VagrantPlugins
             cidr = mask.split(".").map { |e| e.to_i.to_s(2).rjust(8, "0") }.join.count("1").to_s
 
             if network[:type].to_sym == :static
+              unless machine.communicate.test("ipadm show-if #{device}")
+                machine.communicate.execute("#{su_cmd} ipadm create-ip #{device}")
+              end
               if machine.communicate.test("ipadm | grep #{device}/v4")
                 machine.communicate.execute("#{su_cmd} ipadm delete-addr #{device}/v4")
               end
