@@ -33,8 +33,7 @@ describe VagrantPlugins::CommunicatorWinSSH::Communicator do
   let(:config) { double("config", winssh: winssh, ssh: ssh) }
   # Provider mock
   let(:provider) { double("provider") }
-  # UI mock
-  let(:ui) { double("ui") }
+  let(:ui) { Vagrant::UI::Silent.new }
   # SSH info mock
   let(:ssh_info) { double("ssh_info") }
   # Machine mock built with previously defined
@@ -111,10 +110,6 @@ describe VagrantPlugins::CommunicatorWinSSH::Communicator do
   describe "#wait_for_ready" do
     before(&connection_setup)
     context "with no static config (default scenario)" do
-      before do
-        allow(ui).to receive(:detail)
-      end
-
       context "when ssh_info requires a multiple tries before it is ready" do
         before do
           expect(machine).to receive(:ssh_info).
