@@ -33,7 +33,7 @@ describe Vagrant::Action::Builtin::MixinProvisioners do
 
   let(:provisioner_instances) { [provisioner_one,provisioner_two,provisioner_three] }
 
-  let(:ui) { double("ui") }
+  let(:ui) { Vagrant::UI::Silent.new }
   let(:vm) { double("vm", provisioners: provisioner_instances) }
   let(:config) { double("config", vm: vm) }
   let(:machine) { double("machine", ui: ui, config: config) }
